@@ -6,14 +6,12 @@
 #' @param x a 'survfit2' object
 #' @param pvalue_fun function to round and style p-value with
 #' @param prepend_p prepend `"p="` to formatted p-value
-#' @inheritDotParams survival::survdiff -data -formula
+#' @param rho argument passed to  `survival::survdiff(rho=)`
 #'
 #' @return a string
 #' @name survfit2_p
 #'
 #' @examples
-#' library(ggplot2)
-#'
 #' sf <- survfit2(Surv(time, status) ~ sex, data = df_lung)
 #'
 #' sf %>%
@@ -31,7 +29,7 @@ NULL
 
 #' @export
 #' @rdname survfit2_p
-survfit2_p <- function(x, pvalue_fun = format_p, prepend_p = TRUE, ...) {
+survfit2_p <- function(x, pvalue_fun = format_p, prepend_p = TRUE, rho = 0) {
   if (!inherits(x, "survfit2")) {
     cli_abort(
       c("!" = "Argument {.code x} must be class {.cls survfit2},",
@@ -42,10 +40,10 @@ survfit2_p <- function(x, pvalue_fun = format_p, prepend_p = TRUE, ...) {
   survival::survdiff(
     formula = .extract_formula_from_survfit(x),
     data = .extract_data_from_survfit(x),
-    ...
+    rho = rho
   ) %>%
     broom::glance() %>%
-    dplyr::pull(.data$p.value) %>%
+    dplyr::pull("p.value") %>%
     pvalue_fun() %>%
     {dplyr::case_when(
       !prepend_p ~ .,
